Introduction
============

Before investigating the main components of LinchPin -- provisioning, topologies, hooks, layouts, etc.-- you'll learn how to get LinchPin installed and cover some basic concepts. We'll also cover how to use the ``linchpin`` command line interface, some configuration basics, and of course the provisioning providers.


.. toctree::
   :maxdepth: 1

   installation
   getting_started
   intro_config.rst
